@@ -4,8 +4,9 @@ from ..exceptions import PrefixNotDefinedError
 
 
 class CommandOptions:
-
-    def __init__(self, prefix: str = None, overruling_commands: List[str] = None) -> None:
+    def __init__(
+        self, prefix: str = None, overruling_commands: List[str] = None
+    ) -> None:
 
         if prefix is None:
             raise PrefixNotDefinedError("No prefix")
